[go: nahoru, domu]

media: Remove bits_per_channel from AudioDecoderConfig

This CL removes bits_per_channel in favor of just using
bytes_per_channel throughout the codebase. Misc cleanup as seen on TODO.

Bug: <none>
Change-Id: Ic8a9bc0a5c147a1bdaf46085749e4e37e99f5269
Reviewed-on: https://chromium-review.googlesource.com/c/chromium/src/+/4919653
Reviewed-by: Dale Curtis <dalecurtis@chromium.org>
Commit-Queue: Vikram Pasupathy <vpasupathy@chromium.org>
Cr-Commit-Position: refs/heads/main@{#1207187}
diff --git a/media/filters/decrypting_audio_decoder_unittest.cc b/media/filters/decrypting_audio_decoder_unittest.cc
index 926d869..335a7ae 100644
--- a/media/filters/decrypting_audio_decoder_unittest.cc
+++ b/media/filters/decrypting_audio_decoder_unittest.cc
@@ -394,12 +394,12 @@
       .Times(AtMost(1))
       .WillOnce(RunOnceCallback<1>(true));
 
   // The new config is different from the initial config in bits-per-channel,
   // channel layout and samples_per_second.
   AudioDecoderConfig new_config(AudioCodec::kVorbis, kSampleFormatPlanarS16,
                                 CHANNEL_LAYOUT_5_1, 88200, EmptyExtraData(),
                                 EncryptionScheme::kCenc);
-  EXPECT_NE(new_config.bits_per_channel(), config_.bits_per_channel());
+  EXPECT_NE(new_config.bytes_per_channel(), config_.bytes_per_channel());
   EXPECT_NE(new_config.channel_layout(), config_.channel_layout());
   EXPECT_NE(new_config.samples_per_second(), config_.samples_per_second());
   ASSERT_TRUE(new_config.is_encrypted());
@@ -416,12 +416,12 @@
       .Times(AtMost(1))
       .WillOnce(RunOnceCallback<1>(true));
 
   // The new config is different from the initial config in bits-per-channel,
   // channel layout and samples_per_second.
   AudioDecoderConfig new_config(AudioCodec::kVorbis, kSampleFormatPlanarS16,
                                 CHANNEL_LAYOUT_5_1, 88200, EmptyExtraData(),
                                 EncryptionScheme::kUnencrypted);
-  EXPECT_NE(new_config.bits_per_channel(), config_.bits_per_channel());
+  EXPECT_NE(new_config.bytes_per_channel(), config_.bytes_per_channel());
   EXPECT_NE(new_config.channel_layout(), config_.channel_layout());
   EXPECT_NE(new_config.samples_per_second(), config_.samples_per_second());
   ASSERT_FALSE(new_config.is_encrypted());
@@ -394,12 +394,12 @@
       .WillOnce(RunOnceCallback<1>(true));
 
-  // The new config is different from the initial config in bits-per-channel,
+  // The new config is different from the initial config in bytes-per-channel,
   // channel layout and samples_per_second.
   AudioDecoderConfig new_config(AudioCodec::kVorbis, kSampleFormatPlanarS16,
@@ -416,12 +416,12 @@
       .WillOnce(RunOnceCallback<1>(true));
 
-  // The new config is different from the initial config in bits-per-channel,
+  // The new config is different from the initial config in bytes-per-channel,
   // channel layout and samples_per_second.
   AudioDecoderConfig new_config(AudioCodec::kVorbis, kSampleFormatPlanarS16,